@@ -17,6 +17,7 @@ from btNode import Node # have it like this so it will still be possible to sepe
 # local imports
 
 from nexus.btCaptions import BTCaptions
+from nexus.hookSettings import HookSettings
 
 
 # end file header
@@ -28,7 +29,7 @@ class Hook(Node):
     """
     Blackout Nexus hook. Base class for all hooks
     """
-    def __init__(self, **kwargs):
+    def __init__(self, settingsPath=None, **kwargs):
         """
         Constructor for the hook.
         extracting all important infos from the connectHash
@@ -37,6 +38,28 @@ class Hook(Node):
         super(Hook, self).__init__(**kwargs)
         captionsPath = os.path.join(os.path.dirname(os.path.realpath(os.path.abspath(inspect.getfile(self.__class__)))), 'captions.json')
         self.captions = BTCaptions(captionsPath) # TODO: add some docstring to be visibile in the docu
+        if not settingsPath:
+            settingsPath = os.path.join(os.path.dirname(os.path.realpath(os.path.abspath(inspect.getfile(self.__class__)))), 'settings.json')
+        with open(settingsPath) as jsonFile:
+            data = json.load(jsonFile)
+            self.defaultSettings = {}
+            for setting in data:
+                self.defaultSettings[setting] = data[setting]["default"]
+
+    def getDefaultSettings(self):
+        """
+        Returns the default settings for the hook from the settings.json file - these can be used for local debugging. 
+        In production hooks the settings will be transmitted in onMessage
+        """
+        return self.defaultSettings
+
+    # def onSettingsUpdated(self):
+    #     """
+    #     Is called when settings are updated/changed from the instance UI
+    #     This needs to be overloaded.
+    #     """
+    #     if self.debug:
+    #         self.logger.warning("Hook is an abstract super class you need to overwrite onSettingsUpdated.")
 
     def getCaption(self, lang, key):
         """
@@ -56,7 +79,7 @@ class Hook(Node):
         """
         self.memory.addEvent(self.memoryData)
         # Join complete
-        self.subscribe(self.config["id"], 'hookChat', self._onMessage, "onMessage") 
+        self.subscribe(self.config["id"], 'hookChat', self._onMessage, "hookRequest") 
 
         self.subscribe(self.config["id"], "state", self.state)
         self.readyState = "ready"
@@ -77,17 +100,19 @@ class Hook(Node):
         """
         Forwards the correct params to onMessage.
         This method is just for internal use.
-        """
+        """     
+        print('HOOKREQUEST: {}'.format(kwargs)) #TODO: remove       
+        self.onMessage(originalTxt=kwargs["text"] if 'text' in kwargs else None, 
+                        intent=kwargs["intent"] if 'intent' in kwargs else None, 
+                        language=kwargs["language"] if 'language' in kwargs else None, 
+                        entities=kwargs["entities"] if 'entities' in kwargs else None, 
+                        slots=kwargs["slots"] if 'slots' in kwargs else None, 
+                        branchName=kwargs["branch"] if 'branch' in kwargs else None, 
+                        peer=kwargs['sessionId'] if 'sessionId' in kwargs else None, 
+                        settings=kwargs['settings'] if 'settings' in kwargs else None)
+        
 
-        self.onMessage(originalTxt=kwargs["text"]["original"], 
-                        intent=kwargs["intent"], 
-                        language=kwargs["language"], 
-                        entities=kwargs["entities"], 
-                        slots=kwargs["slots"], 
-                        branchName=kwargs["branch"]["name"], 
-                        peer=kwargs)
-
-    def onMessage(self, originalTxt, intent, language, entities, slots, branchName, peer):
+    def onMessage(self, originalTxt, intent, language, entities, slots, branchName, peer, settings):
         """
         Overload for your custum hook! - it needs to trigger say
 
@@ -107,7 +132,9 @@ class Hook(Node):
         :param branchName: Name of the Branch
         :type branchName: String
         :param peer: param to indentify message origin
-        :type peer: dict
+        :type peer: String
+        :param settings: settings for this hook made in the instance
+        :type settings: dict
         
         """
         self.say(peer, {'answer':"Hook needs to overload onMessage"})  # if not overloaded this is what your hook will say
@@ -121,8 +148,12 @@ class Hook(Node):
         :param peer: the peer object handed from onMessage
         :type peer: Object
         """
-        peer["message"] = message
-        self.publish(peer["personalityId"], 'chat', 'hookResponse', peer)
+        # peer["message"] = message
+        # self.publish(group=self.config['id'], topic=peer, funcName='answer', params= {"Hello": "world"}) #TODO: this is not the way it should be - params should be the whole message with answr, hyperrefs...
+        
+        if type(message) == str:
+            message = {'answer':message}
+        self.publish(group=self.config['id'], topic=peer, funcName='hookResponse', params=message)
 
     def _setUp(self):
         """
